DWTObject class

Annotations
  • @JS.new('DWTObject')

Constructors

DWTObject()

Properties

CurrentImageIndexInBuffer → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
HowManyImagesInBuffer → int
no setter
IfShowFileDialog ← bool
no getter
IfShowUI ← bool
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Viewer → dynamic
no setter

Methods

AcquireImage(dynamic obj, Function success, Function error) → void
CloseSource() → void
ConvertToGrayScale(int index) → void
GetImageBitDepth(int index) → int
LoadImageEx(String path, int type, Function success, Function error) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
OpenSource() → void
SaveAllAsMultiPageTIFF(String path, Function success, Function error) → void
SaveAllAsPDF(String path, Function success, Function error) → void
SaveAsJPEG(String path, int index) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited